import InputError from '@/Components/InputError';
import InputLabel from '@/Components/InputLabel';
import PrimaryButton from '@/Components/PrimaryButton';
import TextInput from '@/Components/TextInput';
import { Head, useForm } from '@inertiajs/react';
import { FormEventHandler } from 'react';
import AuthenticatedLayout from '@/Layouts/AuthenticatedLayout';
import { SiteSetting } from '@/types';
import { CreateButton } from '@/Components/ui/create-button';

export default function Index({ ratio, agency_name }: SiteSetting) {
    const { data, setData, post, processing, errors } = useForm({
        agency_name: agency_name ?? '',
        ratio: ratio[0]?.ratio ?? '',
        _method: 'put',
    });

    const onSubmit: FormEventHandler<HTMLFormElement> = (event) => {
        event.preventDefault();
        post(route('settings.update', ratio[0]?.uuid));
    };

    return (
        <AuthenticatedLayout>
            <Head title="Setting" />
            <div className="bg-gradient-to-b from-gray-50 to-gray-100 min-h-screen p-6">
                <div className="bg-white shadow-lg rounded-lg p-6 mx-auto max-w-4xl">
                    {/* Page Title */}
                    <div className="mb-6">
                        <h1 className="text-2xl font-bold text-gray-800">Settings</h1>
                        <p className="text-sm text-gray-500 mt-1">Update your agency name and ratio settings below.</p>
                    </div>

                    {/* Form */}
                    <form onSubmit={onSubmit} className="space-y-6">
                        <div className="grid grid-cols-1 sm:grid-cols-2 gap-6">
                            {/* Agency Name Field */}
                            <div>
                                <InputLabel htmlFor="agency_name" value="Agency Name" />
                                <TextInput
                                    id="agency_name"
                                    name="agency_name"
                                    value={data.agency_name}
                                    className="mt-2 block w-full border-gray-300 rounded-lg shadow-sm focus:border-blue-500 focus:ring-blue-500"
                                    autoComplete="name"
                                    isFocused={true}
                                    onChange={(e) => setData('agency_name', e.target.value)}
                                    required
                                />
                                <InputError message={errors.agency_name} className="mt-1 text-red-500 text-sm" />
                            </div>

                            {/* Ratio Field */}
                            <div>
                                <InputLabel htmlFor="ratio" value="Ratio (%)" />
                                <TextInput
                                    id="ratio"
                                    type="number"
                                    step="any"
                                    name="ratio"
                                    value={data.ratio}
                                    className="mt-2 block w-full border-gray-300 rounded-lg shadow-sm focus:border-blue-500 focus:ring-blue-500"
                                    autoComplete="off"
                                    onChange={(e) => setData('ratio', e.target.value)}
                                    required
                                />
                                <InputError message={errors.ratio} className="mt-1 text-red-500 text-sm" />
                            </div>
                        </div>

                        {/* Submit Button */}
                        <div className="flex justify-end">
                            <CreateButton
                                className="px-6 py-3 rounded-lg shadow-sm"
                                disabled={processing}
                            >
                                Save Setting
                            </CreateButton>
                        </div>
                    </form>
                </div>
            </div>
        </AuthenticatedLayout>
    );
}
